.. _sardana-developers-guide-index:

=================
Developer's Guide
=================

.. toctree::
    :maxdepth: 2
    
    Overview <overview/index>
    howto_macros/index
    howto_controllers/index
    API <api/api_sardana>
    Migration guide <guide_migration>
    Examples <examples/examples>
    Development guidelines <guide_coding>
